<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Category</name>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="362"/>
        <source>All Fonts</source>
        <translation>Todas as fontes</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="363"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="364"/>
        <source>User</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="365"/>
        <source>Favorites</source>
        <translation>Favoritas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="366"/>
        <source>Active</source>
        <translation>Ativas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="367"/>
        <source>Chinese</source>
        <translation>Chinês</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="368"/>
        <source>Monospaced</source>
        <translation>Mono-espaçado</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="139"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="550"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão eliminadas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="544"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="563"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão ativadas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="565"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão desativadas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="576"/>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Ativar</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="578"/>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Desativar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="467"/>
        <source>Apply to all selected font families</source>
        <translation>Aplicar a todas as famílias de fontes selecionadas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="480"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="103"/>
        <source>Broken file</source>
        <translation>Ficheiro corrompido</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="114"/>
        <source>Same version installed</source>
        <translation>Mesma versão instalada</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="125"/>
        <source>System Font</source>
        <translation>Fonte do sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="371"/>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="384"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="403"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="423"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="441"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="521"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="326"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="342"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="358"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1654"/>
        <source>%1 font installed</source>
        <translation>%1 fonte instalada</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1656"/>
        <source>%1 fonts installed</source>
        <translation>%1 fontes instaladas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="474"/>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="562"/>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1661"/>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Falha na instalação de %1 fonte. Não há espaço suficiente em disco.</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1663"/>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Falha na instalação de %1 fontes. Não há espaço suficiente em disco.</translation>
    </message>
    <message>
        <location filename="../libdeepin-font-manager/dcopyfilesmanager.h" line="12"/>
        <source>Fonts</source>
        <translation>Fontes</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <location filename="../libdeepin-font-manager/dfontwidget.cpp" line="127"/>
        <source>Broken file</source>
        <translation>Ficheiro corrompido</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="229"/>
        <source>This font will not be available to applications</source>
        <translation>Esta fonte não estará disponível para as aplicações</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="231"/>
        <source>These fonts will not be available to applications</source>
        <translation>Estas fontes não estarão disponíveis para as aplicações</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="234"/>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>As outras %1 fontes do sistema não podem ser eliminadas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="237"/>
        <source>The font "%1" in use cannot be deleted</source>
        <translation>A fonte "%1" em uso não pode ser eliminada</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="240"/>
        <source>The other %1 system fonts and the font "%2" in use cannot be deleted</source>
        <translation>As outras %1 fontes do sistema e a fonte "%2" em uso não podem ser eliminadas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="204"/>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Tem a certeza que deseja eliminar %1 fonte(s)?</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="140"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="74"/>
        <source>Deleting fonts, please wait...</source>
        <translation>A eliminar fontes, aguarde...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="151"/>
        <source>Font Verification</source>
        <translation>Verificação da fonte</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="252"/>
        <source>No fonts to be installed</source>
        <translation>Sem fontes a instalar</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="186"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="187"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <location filename="../libdeepin-font-manager/dfontpreviewitemdef.h" line="15"/>
        <source>Don't let your dreams be dreams</source>
        <translation>Não deixes os teus sonhos serem sonhos</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="131"/>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="60"/>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="62"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="66"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="72"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Desconhecida</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="78"/>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="79"/>
        <source>Ps name</source>
        <translation>Nome do postscript</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="80"/>
        <source>Trademark</source>
        <translation>Marca registada</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="123"/>
        <source>Copyright</source>
        <translation>Direitos de Autor</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="124"/>
        <source>License Description</source>
        <translation>Descrição da Licença</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../deepin-font-manager/main.cpp" line="60"/>
        <source>Font Manager</source>
        <translation>Gestor de Fontes</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/main.cpp" line="61"/>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>O Gestor de Fontes ajuda os utilizadores a instalar e a gerir fontes.</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="37"/>
        <source>Loading fonts, please wait...</source>
        <translation>A carregar as fontes, aguarde...</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2093"/>
        <source>The font exported to your desktop</source>
        <translation>A fonte exportada para o seu ambiente de trabalho</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2095"/>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fontes exportadas para o seu ambiente de trabalho</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2099"/>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Falha ao exportar 1 fonte. Não há espaço suficiente em disco.</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2102"/>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Falha ao exportar %1 fontes. Não há espaço suficiente em disco.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="63"/>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="71"/>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="297"/>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="73"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="77"/>
        <source>Favorite</source>
        <translation>Adicionar às favoritas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="278"/>
        <source>Unfavorite</source>
        <translation>Remover das favoritas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="80"/>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="83"/>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="75"/>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1875"/>
        <source>deactivated</source>
        <translation>desativada</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1877"/>
        <source>The fonts have been deactivated</source>
        <translation>As fontes foram desativadas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1867"/>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 está a ser utilizada, pelo que não a pode desativar</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1869"/>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Não é possível desativar as fontes do sistema e as fontes em utilização</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1871"/>
        <source>You cannot disable system fonts</source>
        <translation>Não se pode desativar as fontes do sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="130"/>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="143"/>
        <source>Verifying...</source>
        <translation>A verificar...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="77"/>
        <source>Unknown</source>
        <translation>Desconhecida</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="206"/>
        <source>Broken file</source>
        <translation>Ficheiro corrompido</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="227"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="232"/>
        <source>Not Installed</source>
        <translation>Não instalada</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="127"/>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="653"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="838"/>
        <source>No search results</source>
        <translation>Sem resultados</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="860"/>
        <source>No fonts</source>
        <translation>Sem fontes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2275"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2280"/>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2281"/>
        <source>Page up</source>
        <translation>Página para cima</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2282"/>
        <source>Page down</source>
        <translation>Página para baixo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2285"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2286"/>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2287"/>
        <source>Favorite</source>
        <translation>Adicionar às favoritas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2288"/>
        <source>Unfavorite</source>
        <translation>Remover das favoritas</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2289"/>
        <source>Font info</source>
        <translation>Informação da fonte</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="901"/>
        <source>Input preview text</source>
        <translation>Inserir texto de pré-visualização</translation>
    </message>
</context>
</TS>
